# <u>VoDEx</u>: <u>Vo</u>lumetric <u>D</u>ata and <u>Ex</u>periment Manager

[![License BSD-3](https://img.shields.io/pypi/l/vodex.svg?color=green)](https://github.com/LemonJust/vodex/raw/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/vodex.svg?color=green)](https://pypi.org/project/vodex)
[![Python Version](https://img.shields.io/pypi/pyversions/vodex.svg?color=green)](https://python.org)
[![tests](https://github.com/LemonJust/vodex/workflows/tests/badge.svg)](https://github.com/LemonJust/vodex/actions)
[![codecov](https://codecov.io/gh/LemonJust/vodex/branch/main/graph/badge.svg)](https://codecov.io/gh/LemonJust/vodex)
[![napari hub](https://img.shields.io/endpoint?url=https://api.napari-hub.org/shields/napari-vodex)](https://napari-hub.org/plugins/napari-vodex)

VoDEx is an open-source Python library that streamlines the management and analysis of volumetric functional imaging data. It offers a suite of tools for creating, organizing, and storing information pertaining to image acquisition and time annotation. Additionally, it allows for the retrieval of image data based on specific experimental conditions, enabling researchers to access and analyze the data easily. VoDEx is available as both a standalone Python package and a napari plugin, providing a user-friendly solution for processing volumetric functional imaging data, even for researchers without extensive programming experience.

## Quick Start
To get started with `VoDEx`, please see [Quick Start](https://lemonjust.github.io/vodex/qstart/) and [Examples](https://lemonjust.github.io/vodex/examples/).

## API Reference
The [API](https://lemonjust.github.io/vodex/api/) contains the technical implementation of the `VoDEx` project code.

## Contributing
Contributions are very welcome. Please see [Contributions](https://lemonjust.github.io/vodex/contribute/) for more details.

## Data
Some toy datasets are available in [Data](https://lemonjust.github.io/vodex/data/).

## Database
Schematics of the database structure used by VoDEx is available in [Database](https://lemonjust.github.io/vodex/db/).

## GUI
For a quick start with napari-vodex see [napari_vodex](https://lemonjust.github.io/vodex/napari/).

## License
Distributed under the terms of the [BSD-3] license, `vodex` is free and open source software.

## Citing VoDEx
If you use VoDEx in your research, please cite [our paper](https://arxiv.org/abs/2305.07438):

Nadtochiy, A., Luu, P., Fraser, S. E., & Truong, T. V. (2023). VoDEx: a Python library for time annotation and management of volumetric functional imaging data. arXiv preprint arXiv:2305.07438.

<p align="center">
  <img src="assets/vodex_infographics_w_data_and_labels.PNG" alt="cover" width="1200"/>
</p>
